# asf_granule_util

## Install
To install requierments use

    pip install -r requierments.txt

## Tests
To run tests

    python tests/main.py [quick]
    
The quick flag will not run download tests which are a little slow.

## Pypi

To upload to pypi test

    ./upload.sh test


To upload to pypi

    ./upload.sh prod
